# SGBench: A Review and Efficient Implementation of Scene Graph Generation Metrics

Published at [CVPR 2024, Scene Graphs and Graph Representation Learning Workshop](https://sites.google.com/view/sg2rl/index).

## Installation

    pip install sgbench

## Dependencies

- [NumPy](https://numpy.org/) - For faster array operations
- [Pillow](https://pillow.readthedocs.io/en/stable/index.html) - To load ground truth PNG files
- [tifffile](https://github.com/cgohlke/tifffile) - To open TIFF files
- [imagecodecs](https://github.com/cgohlke/imagecodecs) - To support compression of TIFF files

## Citation

If you find this work useful, please consider citing our paper:

``` bibtex
@misc{lorenz2024sgbench,
      title={A Review and Efficient Implementation of Scene Graph Generation Metrics},
      author={Julian Lorenz and Robin Schön and Katja Ludwig and Rainer Lienhart},
      year={2024},
      eprint={2404.09616},
      archivePrefix={arXiv},
      primaryClass={cs.CV}
}
```
